import { CONNECTION_STATUSES, NETWORK_TYPES } from './constants';
import type { Verbs } from './verbs';
export type AlactelClientVerbs = {
    readonly [verb in Verbs as Uncapitalize<verb>]: () => Promise<Record<string, any>>;
};
export interface AlcatelClientBasicStatus {
    imei: string;
    iccid: string;
    device: string;
    connection_status: typeof CONNECTION_STATUSES[keyof typeof CONNECTION_STATUSES] | 'Unknown';
    network_type: typeof NETWORK_TYPES[keyof typeof NETWORK_TYPES] | 'Unknown';
    network_name: string | null;
    strength: number;
}
export interface AlcatelClientExtendedStatus extends AlcatelClientBasicStatus {
    bytes_in: number;
    bytes_out: number;
    bytes_in_rate: number;
    bytes_out_rate: number;
    ipv4_addr: string | null;
    ipv6_addr: string | null;
    rssi: number;
    rsrp: number;
    sinr: number;
    rsrq: number;
}
export interface AlcatelClient extends AlactelClientVerbs {
    login(): Promise<void>;
    connect(): Promise<void>;
    disconnect(): Promise<void>;
    pollExtended(): Promise<AlcatelClientExtendedStatus>;
}
export interface AlcatelClientOptions {
    /** The user name used by the router (default: `admin`).*/
    userName?: string | undefined;
    /** The encryption key used to invoke public verbs (default: `EE5GRouter2020`) */
    publicEncryptionKey?: string | undefined;
    /** The TCL _verification key_ passed as a header (default: `KSDHSDFOGQ5WERYTUIQWERTYUISDFG1HJZXCVCXBN2GDSMNDHKVKFsVBNf`) */
    tclVerificationKey?: string | undefined;
    /** The _system_ salt, used to hash the password before login (default: `e5dl12XYVggihggafXWf0f2YSf2Xngd1`) */
    pbkdf2Salt?: string | undefined;
    /** The number of rounds used to hash the password (default: `1024`) */
    pbkdf2Rounds?: number | undefined;
    /** The length (in bytes) of the hash to generate from the password (default: `64`) */
    pbkdf2KeyLength?: number | undefined;
    /** The algorithm used to hash the password (default: `sha1`) */
    pbkdf2Algorithm?: string | undefined;
}
export declare class AlcatelClient {
    private readonly _hostName;
    private readonly _userName;
    private readonly _hashedPassword;
    private readonly _publicEncryptionKey;
    private readonly _restrictedEncryptionKey;
    private readonly _tclVerificationKey;
    private __sequence;
    private __token;
    constructor(hostName: string, password?: string, options?: AlcatelClientOptions);
    private _post;
    /** Poll basic status (does **not** require login). */
    pollBasic(): Promise<AlcatelClientBasicStatus>;
    /**
     * Poll extended status (**does require** login).
     *
     * @deprecated Use {@link pollBasic()} or {@link pollExtended}.
     */
    poll(): Promise<AlcatelClientExtendedStatus>;
}
